@@ -13,7 +13,7 @@ from http import cookies
 from inspect import iscoroutinefunction
 from pathlib import Path
 from types import GenericAlias
-from typing import Any
+from typing import Any, Literal
 from warnings import warn
 
 from anyio import from_thread
@@ -57,6 +57,7 @@ __all__ = [
     "JSONResponse",
     "Redirect",
     "FtResponse",
+    "Fragment",
     "Client",
     "RouteFuncs",
     "APIRouter",
@@ -300,7 +301,7 @@ class Redirect:
 
 
 class FtResponse:
-    "Wrap an FT response with any Starlette `Response`"
+    "Wrap an FT response with custom status code, headers, or background tasks"
 
     def __init__(
         self,
@@ -315,8 +316,50 @@ class FtResponse:
         self.cls, self.media_type, self.background = cls, media_type, background
 
     def __response__(self, req):
-        """Delegates rendering to the main ResponseRenderer."""
-        return render_response(req, self.content, cls=self.cls, status_code=self.status_code)
+        renderer = ResponseRenderer(req)
+        body_content, kw = renderer._partition_response(self.content)
+        final_content, _ = renderer._render_body(body_content)
+
+        tasks = kw.get("background", self.background)
+        headers = {**(self.headers or {}), **kw.get("headers", {})}
+
+        return self.cls(
+            final_content, status_code=self.status_code, headers=headers, media_type=self.media_type, background=tasks
+        )
+
+
+class Fragment:
+    "Return a Datastar HTML fragment for partial page updates"
+
+    def __init__(
+        self,
+        content,
+        selector: str | None = None,
+        mode: Literal["outer", "inner", "replace", "prepend", "append", "before", "after", "remove"] = "outer",
+        use_view_transition: bool = False,
+        **headers,
+    ):
+        self.content = content
+        self.selector = selector
+        self.mode = mode
+        self.use_view_transition = use_view_transition
+        self.headers = headers
+
+    def __response__(self, req):
+        selector = self.selector
+        if not selector and (element_id := getattr(self.content, "attrs", {}).get("id")):
+            selector = f"#{element_id}"
+
+        headers_dict = {}
+        if selector:
+            headers_dict["datastar-selector"] = selector
+        if self.mode != "outer":
+            headers_dict["datastar-mode"] = self.mode
+        if self.use_view_transition:
+            headers_dict["datastar-use-view-transition"] = "true"
+        headers_dict.update(self.headers)
+
+        return Response(content=to_xml(self.content), media_type="text/html", headers=headers_dict)
 
 
 # ============================================================================
@@ -330,7 +373,12 @@ class ResponseRenderer:
         self.headers = {}
         self.tasks = None
 
-    def process(self, user_response: Any, cls: type = None, status_code: int = 200) -> Response:
+    def process(
+        self,
+        user_response: Any,
+        cls: type = None,
+        status_code: int = 200,
+    ) -> Response:
         """Main method that orchestrates the entire response processing pipeline."""
         if not user_response:
             user_response = ""
@@ -382,7 +430,13 @@ class ResponseRenderer:
             return body, "html"
         return str(body), "html"  # Default to HTML
 
-    def _build_final_response(self, content: Any, content_type: str, cls: type, status_code: int) -> Response:
+    def _build_final_response(
+        self,
+        content: Any,
+        content_type: str,
+        cls: type,
+        status_code: int,
+    ) -> Response:
         """Selects the correct Response class and instantiates it."""
         if cls in (Any, FT, empty):
             cls = None
@@ -391,7 +445,7 @@ class ResponseRenderer:
 
         if content_type == "json":
             return JSONResponse(content, status_code=status_code, headers=self.headers, background=self.tasks)
-        else:  # Default to HTML
+        else:
             return HTMLResponse(content, status_code=status_code, headers=self.headers, background=self.tasks)
 
     def _process_ft_objects(self, resp: Any) -> Any:
@@ -460,17 +514,19 @@ class ResponseRenderer:
         return any(getattr(o, "tag", "") == "html" for o in resp)
 
 
-def render_response(request, user_response: Any, cls: type = None, status_code: int = 200) -> Response:
-    """Main entry point for rendering a user's route return value into an HTTP response.
-
-    This is the clean, modern API for response processing.
-    """
+def render_response(
+    request,
+    user_response: Any,
+    cls: type = None,
+    status_code: int = 200,
+) -> Response:
+    """Main entry point for rendering a user's route return value into an HTTP response."""
     renderer = ResponseRenderer(request)
     return renderer.process(user_response, cls, status_code)
 
 
 def _should_extract_datastar_signals(req):
-    """Check if datastar signal extraction is enabled for this request."""
+    """Check if datastar signal extraction is enabled."""
     if not (hasattr(req, "scope") and req.scope):
         return False
     app = req.scope.get("app")
@@ -481,37 +537,37 @@ def _extract_from_datastar_query(req, arg):
     """Extract parameter from datastar query parameter."""
     datastar_query = req.query_params.get("datastar")
     if not datastar_query:
-        return empty  # Use empty sentinel to indicate not found
+        return empty
     try:
         data = json.loads(datastar_query)
-        if arg in data:
-            return data[arg]  # Return the value even if it's None
-        return empty  # Key not found
+        return data.get(arg, empty)
     except (json.JSONDecodeError, AttributeError):
-        return empty  # Invalid JSON
+        return empty
 
 
 async def _extract_from_datastar_body(req, arg):
     """Extract parameter from datastar signals in request body."""
     if req.method not in {"POST", "PUT", "PATCH", "DELETE"}:
-        return empty  # Use empty sentinel to indicate not found
+        return empty
 
     form_data = form2dict(await parse_form(req))
     if not (isinstance(form_data, dict) and all(k.startswith("$") or k == "datastar" for k in form_data.keys())):
-        return empty  # Not a datastar request
+        return empty
 
-    # Check with $ prefix first, then without
-    if f"${arg}" in form_data:
-        return form_data[f"${arg}"]  # Return the value even if it's None
-    elif arg in form_data:
-        return form_data[arg]  # Return the value even if it's None
-    return empty  # Key not found
+    # Try with $ prefix first, then without
+    return form_data.get(f"${arg}", form_data.get(arg, empty))
 
 
 async def _find_p(req, arg: str, p):
     "In `req` find param named `arg` of type in `p` (`arg` is ignored for body types)"
 
     anno = p.annotation
+
+    from starhtml.datastar import Signal
+
+    if anno is Signal:
+        return Signal(arg, "", _ref_only=True)
+
     # If there's an annotation of special types, return object of that type
     # GenericAlias is a type of typing for iterators like list[int] that is not a class
     if isinstance(anno, type) and not isinstance(anno, GenericAlias):
@@ -554,17 +610,14 @@ async def _find_p(req, arg: str, p):
         res = None
     if res in (empty, None) and req.method in {"POST", "PUT", "PATCH", "DELETE"}:
         res = form2dict(await parse_form(req)).get(arg, None)
-    # Track if we found a value in datastar (even if it's None)
     found_in_datastar = False
 
     if res in (empty, None) and _should_extract_datastar_signals(req):
-        # Try query first
         query_res = _extract_from_datastar_query(req, arg)
         if query_res is not empty:
             res = query_res
             found_in_datastar = True
         else:
-            # Try body if query didn't find it
             body_res = await _extract_from_datastar_body(req, arg)
             if body_res is not empty:
                 res = body_res
@@ -575,7 +628,6 @@ async def _find_p(req, arg: str, p):
 
         raise HTTPException(400, f"Missing required field: {arg}")
 
-    # Only use default if we didn't find the parameter anywhere (including datastar)
     if res in (empty, None) and not found_in_datastar:
         res = p.default
     if anno is empty:
