@@ -4,12 +4,14 @@ import resize_default from "./resize.js";
 import drag_default from "./drag.js";
 import canvas_default from "./canvas.js";
 import position_default from "./position.js";
+import split_default from "./split.js";
 const persist = persist_default;
 const scroll = scroll_default;
 const resize = resize_default;
 const drag = drag_default;
 const canvas = canvas_default;
 const position = position_default;
+const split = split_default;
 export {
   canvas,
   canvas_default as canvasPlugin,
@@ -22,5 +24,7 @@ export {
   resize,
   resize_default as resizePlugin,
   scroll,
-  scroll_default as scrollPlugin
+  scroll_default as scrollPlugin,
+  split,
+  split_default as splitPlugin
 };
