@@ -1467,7 +1467,49 @@ const computePosition = (reference, floating, options) => {
     platform: platformWithCache
   });
 };
-const OPPOSITES = { left: "right", right: "left", top: "bottom", bottom: "top" };
+const SHOW_DELAY_MS = 10;
+const SETTLE_MS = 100;
+const SECONDARY_UPDATE_MS = 150;
+const DEFAULTS = {
+  padding: 10,
+  verticalGapPx: 3,
+  horizontalOverlapPx: -4
+};
+function resolveReferenceEl(el, anchor, config) {
+  if (!anchor?.isConnected) return null;
+  const parentPopover = el.parentElement?.closest("[popover]:popover-open");
+  const side = config.placement.split("-")[0];
+  if (config.container === "parent" && parentPopover) return parentPopover;
+  if (config.container === "auto" && parentPopover && (side === "top" || side === "bottom")) return parentPopover;
+  return anchor;
+}
+function computeDefaultOffset(reference, config, defaults) {
+  let offsetValue = config.offset;
+  const side = config.placement.split("-")[0];
+  try {
+    const htmlRef = reference;
+    const parentPopover = htmlRef?.parentElement?.closest("[popover]:popover-open");
+    const nested = !!parentPopover;
+    const needsEdgeDistance = nested && (config.container === "parent" || config.container === "auto" && (side === "left" || side === "right"));
+    if (needsEdgeDistance && parentPopover) {
+      const parentRect = parentPopover.getBoundingClientRect();
+      const refRect = htmlRef.getBoundingClientRect();
+      const edgeDistances = {
+        right: parentRect.right - refRect.right,
+        left: refRect.left - parentRect.left,
+        bottom: parentRect.bottom - refRect.bottom,
+        top: refRect.top - parentRect.top
+      };
+      const distanceToEdge = edgeDistances[side];
+      const adjust = side === "top" || side === "bottom" ? defaults.verticalGapPx : defaults.horizontalOverlapPx;
+      offsetValue = distanceToEdge + (config.hasCustomOffset ? config.offset : adjust);
+    } else if (nested && config.container !== "none" && !config.hasCustomOffset) {
+      offsetValue = side === "top" || side === "bottom" ? defaults.verticalGapPx : defaults.horizontalOverlapPx;
+    }
+  } catch {
+  }
+  return offsetValue;
+}
 const VALID_PLACEMENTS = [
   "top",
   "bottom",
@@ -1482,205 +1524,439 @@ const VALID_PLACEMENTS = [
   "right-start",
   "right-end"
 ];
-class StablePositioner {
-  constructor(reference, floating, config) {
-    this.reference = reference;
-    this.floating = floating;
-    this.config = config;
-    this.history = [];
-    this.lockedPlacement = null;
-    this.lockUntil = 0;
-  }
-  async position() {
-    const placement = this.getStablePlacement();
-    const zoom = window.devicePixelRatio || 1;
-    const padding = Math.max(20, 30 * zoom);
-    const middleware = [offset(this.config.offset)];
-    if (this.config.flip && !this.isLocked()) {
-      middleware.push(flip({ padding, fallbackStrategy: "bestFit" }));
-    }
-    if (this.config.shift) middleware.push(shift({ padding }));
-    if (this.config.hide) middleware.push(hide());
-    if (this.config.autoSize) {
-      middleware.push(
-        size({
-          apply: ({ availableWidth, availableHeight, elements }) => {
-            Object.assign(elements.floating.style, {
-              maxWidth: `${availableWidth}px`,
-              maxHeight: `${availableHeight}px`
-            });
-          },
-          padding: 10
-        })
-      );
-    }
-    const {
-      x,
-      y,
-      placement: finalPlacement
-    } = await computePosition(this.reference, this.floating, {
-      placement,
-      strategy: this.config.strategy,
-      middleware
-    });
-    const result = {
-      x: Math.round(x),
-      y: Math.round(y),
-      placement: finalPlacement
-    };
-    this.recordHistory(result);
-    return result;
-  }
-  getStablePlacement() {
-    if (this.isLocked() && this.lockedPlacement) return this.lockedPlacement;
-    if (this.detectOscillation()) {
-      const placement = this.findBestPlacement();
-      this.lock(placement);
-      return placement;
-    }
-    return this.config.placement;
-  }
-  detectOscillation() {
-    const now = Date.now();
-    this.history = this.history.filter((h) => now - h.timestamp < 2e3);
-    if (this.history.length < 3) return false;
-    const placements = this.history.map((h) => h.placement);
-    if (new Set(placements).size <= 1) return false;
-    const hasOpposites = Object.entries(OPPOSITES).some(
-      ([side, opposite]) => placements.some((p) => p.includes(side)) && placements.some((p) => p.includes(opposite))
-    );
-    if (hasOpposites) return true;
-    const recent = this.history.slice(-3);
-    const movement = recent.slice(1).reduce((sum, h, i) => sum + Math.abs(h.x - recent[i].x) + Math.abs(h.y - recent[i].y), 0);
-    return movement > 50 && now - recent[0].timestamp < 500;
-  }
-  findBestPlacement() {
-    const rect = this.reference.getBoundingClientRect();
-    const floatingRect = this.floating.getBoundingClientRect();
-    const viewport = { width: window.innerWidth, height: window.innerHeight };
-    const padding = Math.max(20, 30 * (window.devicePixelRatio || 1));
-    const space = {
-      top: (rect.top - padding) / floatingRect.height,
-      bottom: (viewport.height - rect.bottom - padding) / floatingRect.height,
-      left: (rect.left - padding) / floatingRect.width,
-      right: (viewport.width - rect.right - padding) / floatingRect.width
-    };
-    const [base, align] = this.config.placement.split("-");
-    if (space[base] > 0.8) return this.config.placement;
-    const [best] = Object.entries(space).reduce((a, b) => b[1] > a[1] ? b : a);
-    return align ? `${best}-${align}` : best;
-  }
-  lock(placement) {
-    this.lockedPlacement = placement;
-    this.lockUntil = Date.now() + 1500;
-  }
-  isLocked() {
-    return Date.now() < this.lockUntil && this.lockedPlacement !== null;
-  }
-  recordHistory(position) {
-    this.history.push({ ...position, timestamp: Date.now() });
-    if (this.history.length > 10) this.history.shift();
-  }
-  shouldUpdate(x, y, placement, last) {
-    const threshold = Math.max(2, 3 * Math.sqrt(window.devicePixelRatio || 1));
-    return Math.abs(x - last.x) > threshold || Math.abs(y - last.y) > threshold || placement !== last.placement;
-  }
-  reset() {
-    this.history = [];
-    this.lockUntil = 0;
-    this.lockedPlacement = null;
+function adjustFixedY(side, align, refRect, floatRect, offset2) {
+  if (side === "left" || side === "right") {
+    if (align === "start") return refRect.top;
+    if (align === "end") return refRect.bottom - floatRect.height;
+    return refRect.y + (refRect.height - floatRect.height) / 2;
   }
+  if (side === "top") return refRect.top - floatRect.height - offset2;
+  if (side === "bottom") return refRect.bottom + offset2;
+  return refRect.y;
 }
-const extract = (value) => typeof value === "string" ? value : value instanceof Set ? Array.from(value)[0] || "" : "";
-const extractPlacement = (value) => {
-  const str = extract(value) || "bottom";
-  return VALID_PLACEMENTS.includes(str) ? str : "bottom";
+function buildVirtualRef(pageX, pageY, el) {
+  const viewportX = pageX - window.scrollX;
+  const viewportY = pageY - window.scrollY;
+  return {
+    getBoundingClientRect: () => ({
+      x: viewportX,
+      y: viewportY,
+      left: viewportX,
+      top: viewportY,
+      right: viewportX,
+      bottom: viewportY,
+      width: 0,
+      height: 0
+    }),
+    contextElement: el
+  };
+}
+async function computeFloatingPosition(reference, floating, config) {
+  const cfgDefaults = getGlobalConfig().defaults || {};
+  const padding = Number(cfgDefaults.padding ?? DEFAULTS.padding);
+  const offsetValue = computeDefaultOffset(reference, config, {
+    padding,
+    verticalGapPx: Number(cfgDefaults.verticalGapPx ?? DEFAULTS.verticalGapPx),
+    horizontalOverlapPx: Number(cfgDefaults.horizontalOverlapPx ?? DEFAULTS.horizontalOverlapPx)
+  });
+  const mainAxis = config.offsetMain ?? null ?? offsetValue;
+  const crossAxis = config.offsetCross ?? null ?? void 0;
+  const middleware = [
+    crossAxis === void 0 ? offset(mainAxis) : offset({ mainAxis, crossAxis })
+  ];
+  if (config.flip) middleware.push(flip({ padding }));
+  if (config.shift) middleware.push(shift({ padding }));
+  if (config.hide) middleware.push(hide());
+  if (config.autoSize) {
+    middleware.push(
+      size({
+        apply: ({ availableWidth, availableHeight, elements }) => {
+          Object.assign(elements.floating.style, {
+            maxWidth: `${availableWidth}px`,
+            maxHeight: `${availableHeight}px`
+          });
+        },
+        padding: 10
+      })
+    );
+  }
+  const strategy = floating.hasAttribute("popover") ? "fixed" : config.strategy;
+  const { x, y, placement } = await computePosition(reference, floating, {
+    placement: config.placement,
+    strategy,
+    middleware
+  });
+  if (x === 0 && y === 0) {
+    const { width, height } = reference.getBoundingClientRect();
+    if (width === 0 || height === 0) {
+      return { x: -9999, y: -9999, placement };
+    }
+  }
+  let finalY = y;
+  if (strategy === "fixed" && !config.isVirtual) {
+    const refRect = reference.getBoundingClientRect();
+    const floatRect = floating.getBoundingClientRect();
+    const [side, align] = config.placement.split("-");
+    finalY = adjustFixedY(side, align, refRect, floatRect, offsetValue);
+  }
+  const position = { x: Math.round(x), y: Math.round(finalY), placement };
+  return position;
+}
+const shouldUpdatePosition = (current, last, threshold = 2) => Math.abs(current.x - last.x) > threshold || Math.abs(current.y - last.y) > threshold || current.placement !== last.placement;
+const extract = (value) => {
+  if (typeof value === "string") return value;
+  if (value instanceof Set) {
+    const arr = Array.from(value);
+    if (arr.length === 0) return "true";
+    return String(arr[0]) || "";
+  }
+  return "";
 };
-var position_default = {
+const extractPlacement = (value) => {
+  let str = extract(value) || "bottom";
+  str = str.replace(/^(top|bottom|left|right)(start|end)$/i, "$1-$2");
+  const hyphenMap = {
+    topstart: "top-start",
+    topend: "top-end",
+    bottomstart: "bottom-start",
+    bottomend: "bottom-end",
+    leftstart: "left-start",
+    leftend: "left-end",
+    rightstart: "right-start",
+    rightend: "right-end"
+  };
+  const normalized = hyphenMap[str.toLowerCase()] || str;
+  return VALID_PLACEMENTS.includes(normalized) ? normalized : "bottom";
+};
+const injectPositioningCSS = () => {
+  const styleId = "starhtml-positioning-css";
+  if (document.getElementById(styleId)) return;
+  const style = document.createElement("style");
+  style.id = styleId;
+  style.textContent = `
+    [data-positioning="true"]:not([popover]) {
+      visibility: hidden !important;
+      opacity: 0 !important;
+    }
+    [data-positioning="false"]:not([popover]) {
+      visibility: visible !important;
+      opacity: 1 !important;
+      transition: opacity 150ms ease-out;
+    }
+  `;
+  document.head.appendChild(style);
+};
+function getPositionArgNames(signal = "position") {
+  return [
+    `${signal}_x`,
+    `${signal}_y`,
+    `${signal}_placement`,
+    `${signal}_visible`,
+    `${signal}_is_positioning`
+  ];
+}
+function getGlobalConfig() {
+  const cfg = window.__starhtml_position_config || {};
+  return { signal: cfg.signal ?? "position", defaults: cfg.defaults, autoUpdate: cfg.autoUpdate };
+}
+const positionAttributePlugin = {
   type: "attribute",
   name: "position",
   keyReq: "starts",
-  onLoad({ el, value, mods, startBatch, endBatch }) {
+  valReq: "allowed",
+  shouldEvaluate: false,
+  onLoad({ el, value, mods, startBatch, endBatch, mergePatch, getPath, effect }) {
+    injectPositioningCSS();
+    const modSigRaw = extract(mods.get("signal_prefix"));
+    const fallback = getGlobalConfig().signal;
+    const sig = modSigRaw || fallback;
+    const initPatch = {
+      [`${sig}_x`]: 0,
+      [`${sig}_y`]: 0,
+      [`${sig}_placement`]: "bottom",
+      [`${sig}_visible`]: false,
+      [`${sig}_is_positioning`]: false
+    };
+    mergePatch(initPatch);
+    let offsetValue = extract(mods.get("offset"));
+    if (offsetValue?.startsWith("n")) {
+      offsetValue = `-${offsetValue.substring(1)}`;
+    }
+    const hasCustomOffset = !!offsetValue;
+    const offsetMain = extract(mods.get("offset_main"));
+    const offsetCross = extract(mods.get("offset_cross"));
+    const containerParam = extract(mods.get("container")) || "auto";
+    if (!["auto", "none", "parent"].includes(containerParam)) {
+      console.warn(`Invalid container parameter: ${containerParam}. Using 'auto'.`);
+    }
+    const anchorFromValue = value.split(" ")[0].trim();
     const config = {
-      anchor: extract(mods.get("anchor") || value),
+      anchor: extract(mods.get("anchor")) || anchorFromValue,
       placement: extractPlacement(mods.get("placement")),
       strategy: extract(mods.get("strategy")) || "absolute",
-      offset: Number(extract(mods.get("offset"))) || 8,
-      flip: extract(mods.get("flip")) !== "false",
-      shift: extract(mods.get("shift")) !== "false",
-      hide: extract(mods.get("hide")) === "true",
-      autoSize: extract(mods.get("auto_size")) === "true"
+      offset: offsetValue ? Number(offsetValue) : 8,
+      hasCustomOffset,
+      offsetMain: offsetMain ? Number(offsetMain) : null,
+      offsetCross: offsetCross ? Number(offsetCross) : null,
+      // For boolean flags: if the modifier exists (even as empty Set), it's true unless explicitly "false"
+      flip: mods.has("flip") ? extract(mods.get("flip")) !== "false" : true,
+      shift: mods.has("shift") ? extract(mods.get("shift")) !== "false" : true,
+      hide: mods.has("hide") ? extract(mods.get("hide")) !== "false" : false,
+      autoSize: mods.has("auto_size") ? extract(mods.get("auto_size")) !== "false" : false,
+      container: ["auto", "none", "parent"].includes(containerParam) ? containerParam : "auto"
     };
-    const anchor = document.getElementById(config.anchor);
-    if (!anchor && !el.hasAttribute("popover")) return;
-    let positioner = null;
+    const cursorXPathRaw = extract(mods.get("cursor_x"));
+    const cursorYPathRaw = extract(mods.get("cursor_y"));
+    const cursorXPath = cursorXPathRaw?.replace(/^\$/, "");
+    const cursorYPath = cursorYPathRaw?.replace(/^\$/, "");
+    const isCursorMode = Boolean(cursorXPath && cursorYPath);
+    const anchor = config.anchor ? document.getElementById(config.anchor) : null;
+    if (!isCursorMode && !anchor && !el.hasAttribute("popover")) return;
     let cleanup = null;
     let lastPos = { x: -999, y: -999, placement: "" };
-    const updatePosition = async () => {
+    let hasPositioned = false;
+    let showTimer = null;
+    let settlementTimer = null;
+    let domHistory = [];
+    let isLocked = false;
+    let lockUntil = 0;
+    const prepareHiddenState = () => {
+      const baseStyle = { visibility: "hidden", opacity: "0" };
+      const style = config.hide ? { ...baseStyle, transition: "opacity 150ms ease-out" } : baseStyle;
+      if (config.hide || el.hasAttribute("popover")) {
+        Object.assign(el.style, style);
+      }
+    };
+    prepareHiddenState();
+    const checkDOMOscillation = (x, y) => {
+      const now = Date.now();
+      domHistory.push({ x, y, timestamp: now });
+      domHistory = domHistory.filter((h) => now - h.timestamp < 1e3);
+      if (domHistory.length >= 4) {
+        const recent = domHistory.slice(-4);
+        const positions = new Set(recent.map((p) => `${p.x},${p.y}`));
+        if (positions.size === 2 && now - recent[0].timestamp < 300) {
+          isLocked = true;
+          lockUntil = now + 2e3;
+          return true;
+        }
+      }
+      if (now > lockUntil) isLocked = false;
+      return isLocked;
+    };
+    const setPositioning = (state) => {
+      el.setAttribute("data-positioning", state);
+      mergePatch({ [`${sig}_is_positioning`]: state === "true" });
+    };
+    const getTargetElement = () => {
+      if (isCursorMode) return null;
       const target = anchor || document.getElementById(config.anchor);
-      if (!target?.isConnected) return;
+      if (!target?.isConnected) return null;
+      return resolveReferenceEl(el, target, config);
+    };
+    const updatePosition = async () => {
+      const useVirtual = isCursorMode;
+      let reference = null;
+      if (useVirtual) {
+        let pageX = 0;
+        let pageY = 0;
+        try {
+          pageX = Number(getPath(cursorXPath)) || 0;
+          pageY = Number(getPath(cursorYPath)) || 0;
+        } catch {
+        }
+        reference = buildVirtualRef(pageX, pageY, el);
+      } else {
+        const target = getTargetElement();
+        if (!target) return;
+        reference = target;
+      }
+      if (!reference) return;
       startBatch();
       try {
-        positioner ?? (positioner = new StablePositioner(target, el, config));
-        const result = await positioner.position();
-        if (positioner.shouldUpdate(result.x, result.y, result.placement, lastPos)) {
-          Object.assign(el.style, {
-            position: config.strategy,
-            left: `${result.x}px`,
-            top: `${result.y}px`
-          });
-          lastPos = result;
+        const hasDataShow = el.hasAttribute("data-show");
+        const effStrategy = hasDataShow && !mods.has("strategy") ? "fixed" : el.hasAttribute("popover") || useVirtual ? mods.has("strategy") ? config.strategy : "fixed" : config.strategy;
+        const result = await computeFloatingPosition(reference, el, { ...config, strategy: effStrategy, isVirtual: useVirtual });
+        const patch = {};
+        if (shouldUpdatePosition(result, lastPos)) {
+          if (!checkDOMOscillation(result.x, result.y)) {
+            const strategy = effStrategy;
+            Object.assign(el.style, {
+              position: strategy,
+              left: "0px",
+              top: "0px",
+              transform: `translate3d(${result.x}px, ${result.y}px, 0)`,
+              willChange: "transform"
+            });
+            lastPos = result;
+            patch[`${sig}_x`] = result.x;
+            patch[`${sig}_y`] = result.y;
+            patch[`${sig}_placement`] = result.placement;
+            if (settlementTimer) clearTimeout(settlementTimer);
+            settlementTimer = window.setTimeout(() => setPositioning("false"), SETTLE_MS);
+          } else {
+            setPositioning("false");
+          }
         }
+        const isValidPosition = result.x !== 0 && result.y !== 0 && result.x > -1e3 && result.y > -1e3;
+        if (!hasPositioned && isValidPosition) {
+          hasPositioned = true;
+          if (config.hide || el.hasAttribute("popover")) {
+            el.style.visibility = "visible";
+            if (config.hide) {
+              showTimer = window.setTimeout(() => {
+                el.style.opacity = "1";
+              }, SHOW_DELAY_MS);
+            } else {
+              el.style.opacity = "1";
+            }
+          }
+          patch[`${sig}_visible`] = true;
+        }
+        if (Object.keys(patch).length) mergePatch(patch);
       } finally {
         endBatch();
       }
     };
     const isVisible = () => {
-      const style = getComputedStyle(el);
-      return style.display !== "none" && style.visibility !== "hidden" && el.offsetWidth > 0 && el.offsetHeight > 0;
+      const { display, visibility } = getComputedStyle(el);
+      return display !== "none" && visibility !== "hidden" && el.offsetWidth > 0 && el.offsetHeight > 0;
     };
     const start = () => {
-      const target = anchor || document.getElementById(config.anchor);
-      if (!target) return;
+      const useVirtual = isCursorMode;
+      if (useVirtual) {
+        updatePosition();
+        const handleScroll = () => {
+          updatePosition();
+        };
+        window.addEventListener("scroll", handleScroll, true);
+        cleanup = () => {
+          window.removeEventListener("scroll", handleScroll, true);
+        };
+        return;
+      }
+      const target = getTargetElement();
+      if (!target || cleanup) return;
+      if (el.hasAttribute("popover")) {
+        requestAnimationFrame(updatePosition);
+      }
+      const cfg = getGlobalConfig();
+      const au = cfg.autoUpdate || {};
+      const elementResize = au.elementResize ?? false;
+      const layoutShift = au.layoutShift ?? false;
       cleanup = autoUpdate(target, el, updatePosition, {
         ancestorScroll: true,
         ancestorResize: true,
-        elementResize: false,
-        layoutShift: false
+        elementResize,
+        layoutShift
       });
     };
     const stop = () => {
       cleanup?.();
       cleanup = null;
-      positioner?.reset();
-      positioner = null;
+      hasPositioned = false;
+      for (const timer of [showTimer, settlementTimer]) {
+        if (timer) clearTimeout(timer);
+      }
+      showTimer = settlementTimer = null;
+      domHistory = [];
+      isLocked = false;
+      lockUntil = 0;
+      el.removeAttribute("data-positioning");
+      if (config.hide || el.hasAttribute("popover")) {
+        prepareHiddenState();
+      }
+      lastPos = { x: -999, y: -999, placement: "" };
+      mergePatch({ [`${sig}_is_positioning`]: false, [`${sig}_visible`]: false });
     };
+    const handleManualUpdate = () => {
+      if (!cleanup) {
+        start();
+      }
+      requestAnimationFrame(() => updatePosition());
+    };
+    el.addEventListener("position-update", handleManualUpdate);
+    const dataShowAttr = el.getAttribute("data-show") || "";
+    const showSignalMatch = dataShowAttr.match(/\$([a-zA-Z_][\w]*)/);
+    let cleanupEffect = null;
+    let isPositioning = false;
+    if (!el.hasAttribute("popover") && (showSignalMatch || isCursorMode)) {
+      const showSignal = showSignalMatch ? showSignalMatch[1] : null;
+      cleanupEffect = effect(() => {
+        const hasSignal = !!showSignal;
+        const isShown = hasSignal ? Boolean(getPath(showSignal)) : false;
+        if (isShown && !isPositioning) {
+          isPositioning = true;
+          setPositioning("true");
+          start();
+          if (isCursorMode) {
+            updatePosition();
+            setTimeout(() => {
+              updatePosition();
+            }, 0);
+          } else {
+            setTimeout(() => {
+              updatePosition();
+              setTimeout(() => updatePosition(), SECONDARY_UPDATE_MS);
+            }, SHOW_DELAY_MS);
+          }
+        } else if (!isShown && isPositioning) {
+          isPositioning = false;
+          stop();
+        }
+      });
+    }
     if (el.hasAttribute("popover")) {
       const handleToggle = (e) => {
-        if (e.newState === "open") start();
-        else if (e.newState === "closed") stop();
+        if (e.newState === "open") {
+          config.strategy = "fixed";
+          Object.assign(el.style, { margin: "0", inset: "unset" });
+          prepareHiddenState();
+          const isNested = el.parentElement?.closest("[popover]:popover-open") !== null;
+          const startFn = () => el.matches(":popover-open") && start();
+          if (isNested) {
+            setTimeout(startFn, 20);
+          } else {
+            requestAnimationFrame(startFn);
+          }
+        } else if (e.newState === "closed") {
+          stop();
+        }
+      };
+      const handleBeforeToggle = (e) => {
+        if (e.newState === "open") {
+          Object.assign(el.style, { margin: "0", inset: "unset" });
+          prepareHiddenState();
+        }
       };
       el.addEventListener("toggle", handleToggle);
+      el.addEventListener("beforetoggle", handleBeforeToggle);
       return () => {
         el.removeEventListener("toggle", handleToggle);
+        el.removeEventListener("beforetoggle", handleBeforeToggle);
+        el.removeEventListener("position-update", handleManualUpdate);
+        cleanupEffect?.();
         stop();
       };
     }
-    const observer = new MutationObserver(() => {
-      if (isVisible() && !cleanup) start();
-      else if (!isVisible() && cleanup) stop();
-    });
-    observer.observe(el, {
-      attributes: true,
-      attributeFilter: ["style", "class", "data-show"]
-    });
     if (isVisible()) start();
     return () => {
-      observer.disconnect();
+      el.removeEventListener("position-update", handleManualUpdate);
+      cleanupEffect?.();
       stop();
     };
   }
 };
+const positionPlugin = {
+  ...positionAttributePlugin,
+  argNames: [],
+  setConfig(config) {
+    window.__starhtml_position_config = config;
+    const signal = config?.signal ? String(config.signal) : "position";
+    this.argNames = getPositionArgNames(signal);
+  }
+};
+var position_default = positionPlugin;
 export {
   position_default as default
 };
