@@ -11,7 +11,6 @@ This module tests all functionality in src/starhtml/tags.py including:
 
 import pytest
 
-from starhtml.datastar import ds_on_click, ds_show
 from starhtml.tags import (
     H1,
     Button,
@@ -72,7 +71,7 @@ class TestHTMLTagFactories:
 
     def test_html_tags_with_datastar_attrs(self):
         """Test HTML tags with Datastar attributes."""
-        button = Button("Click me", ds_on_click("handleClick()"), ds_show("$isVisible"))
+        button = Button("Click me", data_on_click="handleClick()", data_show="$isVisible")
         assert "data-on-click" in button.attrs
         assert "data-show" in button.attrs
         assert button.attrs["data-on-click"] == "handleClick()"
