@@ -8,6 +8,7 @@ export { default as resizePlugin } from "./resize.js";
 export { default as dragPlugin } from "./drag.js";
 export { default as canvasPlugin } from "./canvas.js";
 export { default as positionPlugin } from "./position.js";
+export { default as splitPlugin } from "./split.js";
 
 import canvasPlugin from "./canvas.js";
 import dragPlugin from "./drag.js";
@@ -15,6 +16,7 @@ import persistPlugin from "./persist.js";
 import positionPlugin from "./position.js";
 import resizePlugin from "./resize.js";
 import scrollPlugin from "./scroll.js";
+import splitPlugin from "./split.js";
 
 export const persist = persistPlugin;
 export const scroll = scrollPlugin;
@@ -22,3 +24,4 @@ export const resize = resizePlugin;
 export const drag = dragPlugin;
 export const canvas = canvasPlugin;
 export const position = positionPlugin;
+export const split = splitPlugin;
